@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.3.19
+Version : 1.3.23
 Author  : Stefano Covino
-Date    : 01/10/2020
+Date    : 28/05/2021
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -189,6 +189,10 @@ History : (28/09/2010) First named version.
         : (23/04/2020) V. 4.5.1.
         : (12/08/2020) V. 4.6.0.
         : (01/10/2020) V. 4.6.1.
+        : (12/05/2021) V. 4.7.0.
+        : (19/05/2021) V. 4.7.1b0
+        : (20/05/2021) V. 4.7.1
+        : (28/05/2021) V. 4.7.2
 """
 
 
@@ -204,6 +208,6 @@ __all__ = ['SRPDatabases', 'SRPCatalogue', 'SRPMath', 'SRPNet',
 
 
 # Version
-__version__ = '4.6.2'
+__version__ = '4.7.2'
 
 #
